@@ -1,4 +1,4 @@
-(* $Id: fl_metascanner.mli 195 2013-06-05 23:29:59Z gerd $
+(* $Id$
  * ----------------------------------------------------------------------
  *
  *)
@@ -8,8 +8,8 @@
 open Fl_metatoken
 
 type formal_pred =
-    [ `Pred of string     (** Positive occurence of a formal predicate var *)
-    | `NegPred of string  (** Negative occurence of a formal predicate var *)
+    [ `Pred of string     (** Positive occurrence of a formal predicate var *)
+    | `NegPred of string  (** Negative occurrence of a formal predicate var *)
     ]
 
 type flavour =
@@ -44,6 +44,8 @@ type pkg_expr =
    *  the definitions of the subpackages.
    *)
 
+exception Error of string
+
 
 val parse : in_channel -> pkg_expr
   (** [parse ch:] 
@@ -51,15 +53,18 @@ val parse : in_channel -> pkg_expr
    * have a syntax compatible with the META format. The return value
    * contains the found definitions for the package and all subpackages.
    *
-   * [exception Stream.Error of string:] is
+   * [exception Error of string:] is
    * raised on syntax errors. The string explains the error.
    *)
 
-val parse2 : in_channel -> pkg_expr
-
-val parse2_lexing : Lexing.lexbuf -> pkg_expr
 val parse_lexing : Lexing.lexbuf -> pkg_expr
 
+
+val print_def : out_channel -> pkg_definition -> unit
+  (** [print_def ch def]:
+    * Outputs the definition to a channel.
+   *)
+
 val print : out_channel -> pkg_expr -> unit
   (** [print ch expr]:
     * Outputs the package expression to a channel.
@@ -87,6 +92,13 @@ val lookup :
    *)
 
 
+val lookup_2 : 
+    string -> string list -> pkg_definition list -> string * formal_pred list
+  (** Like [lookup], but also returns the list of predicates that had to
+      be considered to select the particular variable definition.
+   *)
+
+
 val predicate_exists :
     string -> pkg_definition list -> bool
   (** [predicate_exists variable_name def]:
